==> wildfly-controller-client-2.0.10.Final-sources.jar: org/jboss/as/controller/client/helpers/ClientConstants.java <==
/*
* JBoss, Home of Professional Open Source.
* Copyright 2006, Red Hat Middleware LLC, and individual contributors
* as indicated by the @author tags. See the copyright.txt file in the
* distribution for a full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.as.controller.client.helpers;

/**
 * Constants for strings frequently used in management operations.
 *
 * @author <a href="kabir.khan@jboss.com">Kabir Khan</a>
 */
public class ClientConstants {
    public static final String ADD = "add";
    public static final String ADDRESS = "address";
    public static final String ATTACHED_STREAMS = "attached-streams";
    @Deprecated
    public static final String AUTO_START = "auto-start";
    public static final String CHILD_TYPE = "child-type";
    public static final String COMPOSITE = "composite";
    public static final String CONTENT = "content";
    public static final String DEPLOYMENT = "deployment";
    public static final String DEPLOYMENT_DEPLOY_OPERATION = "deploy";
    public static final String DEPLOYMENT_FULL_REPLACE_OPERATION = "full-replace-deployment";
    public static final String DEPLOYMENT_REDEPLOY_OPERATION = "redeploy";
    public static final String DEPLOYMENT_REMOVE_OPERATION = "remove";
    public static final String DEPLOYMENT_REPLACE_OPERATION = "replace-deployment";
    public static final String DEPLOYMENT_UNDEPLOY_OPERATION = "undeploy";
    public static final String EXTENSION = "extension";
    public static final String FILE = "file";
    public static final String FAILURE_DESCRIPTION = "failure-description";
    public static final String GROUP = "group";
    public static final String HOST = "host";
    public static final String HOST_STATE = "host-state";
    public static final String INCLUDE_RUNTIME = "include-runtime";
    public static final String INPUT_STREAM_INDEX = "input-stream-index";
    public static final String NAME = "name";
    public static final String OP = "operation";
    public static final String OPERATION_HEADERS = "operation-headers";
    public static final String OP_ADDR = "address";
    public static final String OUTCOME = "outcome";
    public static final String PATH = "path";
    public static final String PROXIES = "proxies";
    public static final String READ_ATTRIBUTE_OPERATION = "read-attribute";
    public static final String READ_CHILDREN_NAMES_OPERATION = "read-children-names";
    public static final String READ_RESOURCE_OPERATION = "read-resource";
    public static final String RECURSIVE = "recursive";
    public static final String RECURSIVE_DEPTH = "recursive-depth";
    public static final String REMOVE_OPERATION = "remove";
    public static final String RESPONSE_HEADERS = "response-headers";
    public static final String RESULT = "result";
    public static final String ROLLBACK_ON_RUNTIME_FAILURE = "rollback-on-runtime-failure";
    public static final String ROLLOUT_PLAN = "rollout-plan";
    public static final String RUNTIME_NAME = "runtime-name";
    public static final String SERVER = "server";
    public static final String SERVER_CONFIG = "server-config";
    public static final String SERVER_GROUP = "server-group";
    public static final String SOCKET_BINDING = "socket-binding";
    public static final String SOCKET_BINDING_GROUP = "socket-binding-group";
    public static final String STATUS = "status";
    public static final String STEPS = "steps";
    public static final String SUBSYSTEM = "subsystem";
    public static final String SUCCESS = "success";
    public static final String TO_REPLACE = "to-replace";
    public static final String UNDEFINE_ATTRIBUTE_OPERATION = "undefine-attribute";
    public static final String UUID = "uuid";
    public static final String VALUE = "value";
    public static final String WRITE_ATTRIBUTE_OPERATION = "write-attribute";

    public static final String CONTROLLER_PROCESS_STATE_STARTING = "starting";
    public static final String CONTROLLER_PROCESS_STATE_RUNNING = "running";
    public static final String CONTROLLER_PROCESS_STATE_RELOAD_REQUIRED = "reload-required";
    public static final String CONTROLLER_PROCESS_STATE_RESTART_REQUIRED = "restart-required";
    public static final String CONTROLLER_PROCESS_STATE_STOPPING = "stopping";
}

==> wildfly-controller-client-21.1.1.Final-sources.jar: org/jboss/as/controller/client/helpers/ClientConstants.java <==
/*
* JBoss, Home of Professional Open Source.
* Copyright 2006, Red Hat Middleware LLC, and individual contributors
* as indicated by the @author tags. See the copyright.txt file in the
* distribution for a full listing of individual contributors.
*
* This is free software; you can redistribute it and/or modify it
* under the terms of the GNU Lesser General Public License as
* published by the Free Software Foundation; either version 2.1 of
* the License, or (at your option) any later version.
*
* This software is distributed in the hope that it will be useful,
* but WITHOUT ANY WARRANTY; without even the implied warranty of
* MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the GNU
* Lesser General Public License for more details.
*
* You should have received a copy of the GNU Lesser General Public
* License along with this software; if not, write to the Free
* Software Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA
* 02110-1301 USA, or see the FSF site: http://www.fsf.org.
*/
package org.jboss.as.controller.client.helpers;

/**
 * Constants for strings frequently used in management operations.
 *
 * @author <a href="kabir.khan@jboss.com">Kabir Khan</a>
 */
public class ClientConstants {
    public static final String ADD = "add";
    public static final String ADD_CONTENT = "add-content";
    public static final String ADDRESS = "address";
    public static final String ARCHIVE = "archive";
    public static final String ATTACHED_STREAMS = "attached-streams";
    public static final String AUTO_START = "auto-start";
    public static final String CHILD_TYPE = "child-type";
    public static final String COMPOSITE = "composite";
    public static final String CONTENT = "content";
    public static final String DEPLOYMENT = "deployment";
    public static final String DEPLOYMENT_BROWSE_CONTENT_OPERATION = "browse-content";
    public static final String DEPLOYMENT_DEPLOY_OPERATION = "deploy";
    public static final String DEPLOYMENT_FULL_REPLACE_OPERATION = "full-replace-deployment";
    public static final String DEPLOYMENT_REDEPLOY_OPERATION = "redeploy";
    public static final String DEPLOYMENT_REMOVE_OPERATION = "remove";
    public static final String DEPLOYMENT_REPLACE_OPERATION = "replace-deployment";
    public static final String DEPLOYMENT_UNDEPLOY_OPERATION = "undeploy";
    public static final String EMPTY = "empty";
    public static final String EXPLODE = "explode";
    public static final String EXTENSION = "extension";
    public static final String FAILED = "failed";
    public static final String FILE = "file";
    public static final String FAILURE_DESCRIPTION = "failure-description";
    public static final String GROUP = "group";
    public static final String HOST = "host";
    public static final String HOST_STATE = "host-state";
    public static final String INCLUDE_RUNTIME = "include-runtime";
    public static final String INPUT_STREAM_INDEX = "input-stream-index";
    public static final String NAME = "name";
    public static final String OP = "operation";
    public static final String OPERATION_HEADERS = "operation-headers";
    public static final String OP_ADDR = "address";
    public static final String OUTCOME = "outcome";
    public static final String PATH = "path";
    public static final String PATHS = "paths";
    public static final String PROXIES = "proxies";
    public static final String READ_ATTRIBUTE_OPERATION = "read-attribute";
    public static final String READ_CHILDREN_NAMES_OPERATION = "read-children-names";
    public static final String READ_CONTENT_OPERATION = "read-content";
    public static final String READ_RESOURCE_OPERATION = "read-resource";
    public static final String RECURSIVE = "recursive";
    public static final String RECURSIVE_DEPTH = "recursive-depth";
    public static final String REMOVE_CONTENT = "remove-content";
    public static final String REMOVE_OPERATION = "remove";
    public static final String RESPONSE_HEADERS = "response-headers";
    public static final String RESULT = "result";
    public static final String ROLLBACK_ON_RUNTIME_FAILURE = "rollback-on-runtime-failure";
    public static final String ROLLOUT_PLAN = "rollout-plan";
    public static final String RUNTIME_CONFIGURATION_STATE = "runtime-configuration-state";
    public static final String RUNTIME_NAME = "runtime-name";
    public static final String SERVER = "server";
    public static final String SERVER_CONFIG = "server-config";
    public static final String SERVER_GROUP = "server-group";
    public static final String SOCKET_BINDING = "socket-binding";
    public static final String SOCKET_BINDING_GROUP = "socket-binding-group";
    public static final String STATUS = "status";
    public static final String STEPS = "steps";
    public static final String SUBSYSTEM = "subsystem";
    public static final String SUCCESS = "success";
    public static final String TARGET_PATH = "target-path";
    public static final String TO_REPLACE = "to-replace";
    public static final String UNDEFINE_ATTRIBUTE_OPERATION = "undefine-attribute";
    public static final String UUID = "uuid";
    public static final String VALUE = "value";
    public static final String WRITE_ATTRIBUTE_OPERATION = "write-attribute";

    public static final String CONTROLLER_PROCESS_STATE_STARTING = "starting";
    public static final String CONTROLLER_PROCESS_STATE_OK = "ok";
    public static final String CONTROLLER_PROCESS_STATE_RUNNING = "running";
    public static final String CONTROLLER_PROCESS_STATE_RELOAD_REQUIRED = "reload-required";
    public static final String CONTROLLER_PROCESS_STATE_RESTART_REQUIRED = "restart-required";
    public static final String CONTROLLER_PROCESS_STATE_STOPPING = "stopping";
    public static final String CONTROLLER_PROCESS_STATE_STOPPED = "stopped";

    public static final String RUNNING_STATE_PRE_SUSPEND = "pre-suspend";
    public static final String RUNNING_STATE_NORMAL = "normal";
    public static final String RUNNING_STATE_ADMIN_ONLY = "admin-only";
    public static final String RUNNING_STATE_SUSPENDED = "suspended";
    public static final String RUNNING_STATE_SUSPENDING = "suspending";
}
